==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/IdpDiscoveryPolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AppAndInstancePolicyRuleCondition;
import com.okta.sdk.resource.model.PlatformPolicyRuleCondition;
import com.okta.sdk.resource.model.PolicyNetworkCondition;
import com.okta.sdk.resource.model.UserIdentifierPolicyRuleCondition;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * IdpDiscoveryPolicyRuleCondition
 */
@JsonPropertyOrder({ IdpDiscoveryPolicyRuleCondition.JSON_PROPERTY_APP,
        IdpDiscoveryPolicyRuleCondition.JSON_PROPERTY_NETWORK,
        IdpDiscoveryPolicyRuleCondition.JSON_PROPERTY_USER_IDENTIFIER,
        IdpDiscoveryPolicyRuleCondition.JSON_PROPERTY_PLATFORM })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class IdpDiscoveryPolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_APP = "app";
    private AppAndInstancePolicyRuleCondition app;

    public static final String JSON_PROPERTY_NETWORK = "network";
    private PolicyNetworkCondition network;

    public static final String JSON_PROPERTY_USER_IDENTIFIER = "userIdentifier";
    private UserIdentifierPolicyRuleCondition userIdentifier;

    public static final String JSON_PROPERTY_PLATFORM = "platform";
    private PlatformPolicyRuleCondition platform;

    public IdpDiscoveryPolicyRuleCondition() {
    }

    public IdpDiscoveryPolicyRuleCondition app(AppAndInstancePolicyRuleCondition app) {

        this.app = app;
        return this;
    }

    /**
     * Get app
     *
     * @return app
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_APP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AppAndInstancePolicyRuleCondition getApp() {
        return app;
    }

    @JsonProperty(JSON_PROPERTY_APP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setApp(AppAndInstancePolicyRuleCondition app) {
        this.app = app;
    }

    public IdpDiscoveryPolicyRuleCondition network(PolicyNetworkCondition network) {

        this.network = network;
        return this;
    }

    /**
     * Get network
     *
     * @return network
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_NETWORK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PolicyNetworkCondition getNetwork() {
        return network;
    }

    @JsonProperty(JSON_PROPERTY_NETWORK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setNetwork(PolicyNetworkCondition network) {
        this.network = network;
    }

    public IdpDiscoveryPolicyRuleCondition userIdentifier(UserIdentifierPolicyRuleCondition userIdentifier) {

        this.userIdentifier = userIdentifier;
        return this;
    }

    /**
     * Get userIdentifier
     *
     * @return userIdentifier
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_USER_IDENTIFIER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserIdentifierPolicyRuleCondition getUserIdentifier() {
        return userIdentifier;
    }

    @JsonProperty(JSON_PROPERTY_USER_IDENTIFIER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUserIdentifier(UserIdentifierPolicyRuleCondition userIdentifier) {
        this.userIdentifier = userIdentifier;
    }

    public IdpDiscoveryPolicyRuleCondition platform(PlatformPolicyRuleCondition platform) {

        this.platform = platform;
        return this;
    }

    /**
     * Get platform
     *
     * @return platform
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PLATFORM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PlatformPolicyRuleCondition getPlatform() {
        return platform;
    }

    @JsonProperty(JSON_PROPERTY_PLATFORM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPlatform(PlatformPolicyRuleCondition platform) {
        this.platform = platform;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        IdpDiscoveryPolicyRuleCondition idpDiscoveryPolicyRuleCondition = (IdpDiscoveryPolicyRuleCondition) o;
        return Objects.equals(this.app, idpDiscoveryPolicyRuleCondition.app)
                && Objects.equals(this.network, idpDiscoveryPolicyRuleCondition.network)
                && Objects.equals(this.userIdentifier, idpDiscoveryPolicyRuleCondition.userIdentifier)
                && Objects.equals(this.platform, idpDiscoveryPolicyRuleCondition.platform);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(app, network, userIdentifier, platform);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class IdpDiscoveryPolicyRuleCondition {\n");
        sb.append("    app: ").append(toIndentedString(app)).append("\n");
        sb.append("    network: ").append(toIndentedString(network)).append("\n");
        sb.append("    userIdentifier: ").append(toIndentedString(userIdentifier)).append("\n");
        sb.append("    platform: ").append(toIndentedString(platform)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/IdpDiscoveryPolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AppAndInstancePolicyRuleCondition;
import com.okta.sdk.resource.model.PlatformPolicyRuleCondition;
import com.okta.sdk.resource.model.PolicyNetworkCondition;
import com.okta.sdk.resource.model.UserIdentifierPolicyRuleCondition;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * IdpDiscoveryPolicyRuleCondition
 */
@JsonPropertyOrder({ IdpDiscoveryPolicyRuleCondition.JSON_PROPERTY_APP,
        IdpDiscoveryPolicyRuleCondition.JSON_PROPERTY_NETWORK,
        IdpDiscoveryPolicyRuleCondition.JSON_PROPERTY_USER_IDENTIFIER,
        IdpDiscoveryPolicyRuleCondition.JSON_PROPERTY_PLATFORM })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class IdpDiscoveryPolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_APP = "app";
    private AppAndInstancePolicyRuleCondition app;

    public static final String JSON_PROPERTY_NETWORK = "network";
    private PolicyNetworkCondition network;

    public static final String JSON_PROPERTY_USER_IDENTIFIER = "userIdentifier";
    private UserIdentifierPolicyRuleCondition userIdentifier;

    public static final String JSON_PROPERTY_PLATFORM = "platform";
    private PlatformPolicyRuleCondition platform;

    public IdpDiscoveryPolicyRuleCondition() {
    }

    public IdpDiscoveryPolicyRuleCondition app(AppAndInstancePolicyRuleCondition app) {

        this.app = app;
        return this;
    }

    /**
     * Get app
     *
     * @return app
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_APP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AppAndInstancePolicyRuleCondition getApp() {
        return app;
    }

    @JsonProperty(JSON_PROPERTY_APP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setApp(AppAndInstancePolicyRuleCondition app) {
        this.app = app;
    }

    public IdpDiscoveryPolicyRuleCondition network(PolicyNetworkCondition network) {

        this.network = network;
        return this;
    }

    /**
     * Get network
     *
     * @return network
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_NETWORK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PolicyNetworkCondition getNetwork() {
        return network;
    }

    @JsonProperty(JSON_PROPERTY_NETWORK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setNetwork(PolicyNetworkCondition network) {
        this.network = network;
    }

    public IdpDiscoveryPolicyRuleCondition userIdentifier(UserIdentifierPolicyRuleCondition userIdentifier) {

        this.userIdentifier = userIdentifier;
        return this;
    }

    /**
     * Get userIdentifier
     *
     * @return userIdentifier
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_USER_IDENTIFIER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserIdentifierPolicyRuleCondition getUserIdentifier() {
        return userIdentifier;
    }

    @JsonProperty(JSON_PROPERTY_USER_IDENTIFIER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUserIdentifier(UserIdentifierPolicyRuleCondition userIdentifier) {
        this.userIdentifier = userIdentifier;
    }

    public IdpDiscoveryPolicyRuleCondition platform(PlatformPolicyRuleCondition platform) {

        this.platform = platform;
        return this;
    }

    /**
     * Get platform
     *
     * @return platform
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PLATFORM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PlatformPolicyRuleCondition getPlatform() {
        return platform;
    }

    @JsonProperty(JSON_PROPERTY_PLATFORM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPlatform(PlatformPolicyRuleCondition platform) {
        this.platform = platform;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        IdpDiscoveryPolicyRuleCondition idpDiscoveryPolicyRuleCondition = (IdpDiscoveryPolicyRuleCondition) o;
        return Objects.equals(this.app, idpDiscoveryPolicyRuleCondition.app)
                && Objects.equals(this.network, idpDiscoveryPolicyRuleCondition.network)
                && Objects.equals(this.userIdentifier, idpDiscoveryPolicyRuleCondition.userIdentifier)
                && Objects.equals(this.platform, idpDiscoveryPolicyRuleCondition.platform);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(app, network, userIdentifier, platform);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class IdpDiscoveryPolicyRuleCondition {\n");
        sb.append("    app: ").append(toIndentedString(app)).append("\n");
        sb.append("    network: ").append(toIndentedString(network)).append("\n");
        sb.append("    userIdentifier: ").append(toIndentedString(userIdentifier)).append("\n");
        sb.append("    platform: ").append(toIndentedString(platform)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
